@@ -117,8 +117,6 @@ batchalign.add_command(train, "models")
 @click.option("--pauses", type=bool, default=False, help="Should we try to bullet each word or should we try to add pauses in between words by grouping them? Default: no pauses.", is_flag=True)
 @click.option("--wor/--nowor",
               default=True, help="Should we write word level alignment line? Default to yes.")
-@click.option("--data",
-              help="the URL of the data", type=str)
 @click.pass_context
 def align(ctx, in_dir, out_dir, whisper, wav2vec, tencent, funaudio, **kwargs):
     """Align transcripts against corresponding media files."""
@@ -172,9 +170,6 @@ def align(ctx, in_dir, out_dir, whisper, wav2vec, tencent, funaudio, **kwargs):
               default=False, help="Perform speaker diarization (this flag is ignored with Rev.AI)")
 @click.option("--wor/--nowor",
               default=False, help="Should we write word level alignment line? Default to no.")
-@click.option("--data",
-              help="the URL of the data",
-              type=str)
 @click.option("--lang",
               help="sample language in three-letter ISO 3166-1 alpha-3 code",
               show_default=True,
@@ -352,9 +347,6 @@ def utseg(ctx, in_dir, out_dir, lang, num_speakers, **kwargs):
               show_default=True,
               default="eng",
               type=str)
-@click.option("--data",
-              help="the URL of the data",
-              type=str)
 @click.option("-n", "--num_speakers", type=int, help="number of speakers in the language sample", default=2)
 @click.pass_context
 def benchmark(ctx, in_dir, out_dir, lang, num_speakers, whisper, tencent, **kwargs):
@@ -385,7 +377,53 @@ def benchmark(ctx, in_dir, out_dir, lang, num_speakers, whisper, tencent, **kwar
     _dispatch("benchmark", lang, num_speakers, ["mp3", "mp4", "wav"], ctx,
               in_dir, out_dir,
               loader, writer, C,
-              asr="whisper" if whisper else ("funaudio" if funaudio else ("tencent" if tencent else "rev")), **kwargs)
+              asr="whisper" if whisper else ("funaudio" if funaudio else ("tencent" if tencent else "rev")),
+              **kwargs)
+    
+
+#################### AVQI ################################
+
+@batchalign.command()
+@click.argument("cs_file", type=click.Path(exists=True, file_okay=True))
+@click.argument("sv_file", type=click.Path(exists=True, file_okay=True))
+@click.option("--lang",
+              help="sample language in three-letter ISO 3166-1 alpha-3 code",
+              show_default=True,
+              default="eng",
+              type=str)
+@click.pass_context
+def avqi(ctx, cs_file, sv_file, lang, **kwargs):
+    """Calculate Acoustic Voice Quality Index (AVQI) from continuous speech and sustained vowel audio files."""
+    
+    # Import AVQI engine
+    from batchalign.pipelines.avqi import AVQIEngine
+    
+    # Get output file path (same directory as cs_file, with .avqi.txt extension)
+    cs_path = Path(cs_file)
+    output_file = cs_path.with_suffix('.avqi.txt')
+    
+    # Create AVQI engine
+    avqi_engine = AVQIEngine()
+    
+    try:
+        # Calculate AVQI
+        C.print(f"\n[blue]Calculating AVQI[/blue] for:")
+        C.print(f"  Continuous Speech: [cyan]{cs_file}[/cyan]")
+        C.print(f"  Sustained Vowel:   [cyan]{sv_file}[/cyan]")
+        C.print(f"  Language:          [cyan]{lang}[/cyan]")
+        C.print(f"  Output:            [cyan]{output_file}[/cyan]\n")
+        
+        results = avqi_engine.analyze(cs_file, sv_file, str(output_file), lang)
+        
+        C.print(f"[bold green]✓ AVQI calculation completed![/bold green]")
+        C.print(f"[bold]AVQI Score: {results['avqi']:.3f}[/bold]")
+        C.print(f"Results saved to: [cyan]{output_file}[/cyan]\n")
+        
+    except Exception as e:
+        C.print(f"[bold red]ERROR[/bold red]: {str(e)}")
+        if ctx.obj["verbose"] > 0:
+            import traceback
+            C.print(traceback.format_exc())
 
 
 #################### SETUP ################################
@@ -409,3 +447,4 @@ def version(ctx, **kwargs):
            f"[italic]{RELEASE_NOTES.strip()}[/italic]"+"\n" +
            "\nDeveloped by Brian MacWhinney and Houjun Liu")
     C.print("\n\n"+ptr+"\n\n")
+
