@@ -7,7 +7,9 @@ from batchalign import (WhisperEngine, WhisperFAEngine, StanzaEngine, RevEngine,
                         NgramRetraceEngine, DisfluencyReplacementEngine, WhisperUTREngine,
                         RevUTREngine, EvaluationEngine, WhisperXEngine, NemoSpeakerEngine,
                         StanzaUtteranceEngine, CorefEngine, Wave2VecFAEngine, TencentEngine,
-                        OAIWhisperEngine, TencentUTREngine, AliyunEngine, FunAudioEngine, FunAudioUTREngine)
+                        OAIWhisperEngine, TencentUTREngine, AliyunEngine, FunAudioEngine,
+                        FunAudioUTREngine, SeamlessTranslationModel, GoogleTranslateEngine,
+                        OAIWhisperEngine, PyannoteEngine)
 
 from batchalign import BatchalignPipeline
 from batchalign.models import resolve
@@ -23,7 +25,7 @@ DEFAULT_PACKAGES = {
     "asr": "whisper_oai",
     "utr": "whisper_utr",
     "fa": "whisper_fa",
-    "speaker": "nemo_speaker",
+    "speaker": "pyannote",
     "morphosyntax": "stanza",
     "disfluency": "replacement",
     "retracing": "ngram",
@@ -148,6 +150,8 @@ def dispatch_pipeline(pkg_str, lang, num_speakers=None, **arg_overrides):
             engines.append(FunAudioEngine())
         elif engine ==  "funaudio_utr":
             engines.append(FunAudioUTREngine(lang=lang))
+        elif engine == "pyannote":
+            engines.append(PyannoteEngine())
 
 
     L.debug(f"Done initalizing packages.")
